@@ -14,6 +14,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('cksum', cksum_command_output)
+
+    or
+
     import jc.parsers.cksum
     result = jc.parsers.cksum.parse(cksum_command_output)
 
@@ -58,8 +63,6 @@ class info():
     description = '`cksum` and `sum` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['cksum', 'sum']
 
@@ -96,7 +99,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
