@@ -1,6 +1,8 @@
-"""jc - JSON CLI output utility `crontab -l` command output and crontab file parser
+"""jc - JSON CLI output utility `crontab -l` command output and crontab
+file parser
 
-This version of the `crontab -l` parser supports output that contains user information for processes.
+This version of the `crontab -l` parser supports output that contains user
+information for processes.
 
 Usage (cli):
 
@@ -8,6 +10,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('crontab_u', crontab_u_output)
+
+    or
+
     import jc.parsers.crontab_u
     result = jc.parsers.crontab_u.parse(crontab_u_output)
 
@@ -52,7 +59,7 @@ Examples:
       "variables": [
         {
           "name": "PATH",
-          "value": "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"
+          "value": "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sb..."
         },
         {
           "name": "SHELL",
@@ -77,7 +84,7 @@ Examples:
             "*"
           ],
           "user": "root",
-          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.daily )"
+          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts ..."
         },
         {
           "minute": [
@@ -96,7 +103,7 @@ Examples:
             "7"
           ],
           "user": "root",
-          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.weekly )"
+          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts ..."
         },
         {
           "minute": [
@@ -115,7 +122,7 @@ Examples:
             "*"
           ],
           "user": "root",
-          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.monthly )"
+          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts ..."
         }
       ]
     }
@@ -125,7 +132,7 @@ Examples:
       "variables": [
         {
           "name": "PATH",
-          "value": "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin"
+          "value": "/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/..."
         },
         {
           "name": "SHELL",
@@ -140,7 +147,7 @@ Examples:
           "month": "*",
           "day_of_week": "*",
           "user": "root",
-          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.daily )"
+          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts ..."
         },
         {
           "minute": "47",
@@ -149,7 +156,7 @@ Examples:
           "month": "*",
           "day_of_week": "7",
           "user": "root",
-          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.weekly )"
+          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts ..."
         },
         {
           "minute": "52",
@@ -158,7 +165,7 @@ Examples:
           "month": "*",
           "day_of_week": "*",
           "user": "root",
-          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.monthly )"
+          "command": "test -x /usr/sbin/anacron || ( cd / && run-parts ..."
         }
       ]
     }
@@ -173,9 +180,6 @@ class info():
     description = '`crontab` file parser with user support'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-    # details = 'enter any other details here'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'aix', 'freebsd']
 
 
@@ -215,7 +219,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
