@@ -1,6 +1,8 @@
 """jc - JSON CLI output utility `csv` file parser
 
-The `csv` parser will attempt to automatically detect the delimiter character. If the delimiter cannot be detected it will default to comma. The first row of the file must be a header row.
+The `csv` parser will attempt to automatically detect the delimiter
+character. If the delimiter cannot be detected it will default to comma.
+The first row of the file must be a header row.
 
 Usage (cli):
 
@@ -8,12 +10,18 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('csv', csv_output)
+
+    or
+
     import jc.parsers.csv
     result = jc.parsers.csv.parse(csv_output)
 
 Schema:
 
-    csv file converted to a Dictionary: https://docs.python.org/3/library/csv.html
+    csv file converted to a Dictionary:
+    https://docs.python.org/3/library/csv.html
 
     [
       {
@@ -25,7 +33,7 @@ Schema:
 Examples:
 
     $ cat homes.csv
-    "Sell", "List", "Living", "Rooms", "Beds", "Baths", "Age", "Acres", "Taxes"
+    "Sell", "List", "Living", "Rooms", "Beds", "Baths", "Age", "Acres"...
     142, 160, 28, 10, 5, 3,  60, 0.28,  3167
     175, 180, 18,  8, 4, 1,  12, 0.43,  4033
     129, 132, 13,  6, 3, 1,  41, 0.33,  1471
@@ -80,8 +88,6 @@ class info():
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     details = 'Using the python standard csv library'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
 
 
@@ -98,7 +104,8 @@ def _process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Each Dictionary represents a row in the csv file.
+        List of Dictionaries. Each Dictionary represents a row in the csv
+        file.
     """
 
     # No further processing
@@ -112,7 +119,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
