@@ -1,6 +1,7 @@
 """jc - JSON CLI output utility `dpkg -l` command output parser
 
-Set the `COLUMNS` environment variable to a large value to avoid field truncation. For example:
+Set the `COLUMNS` environment variable to a large value to avoid field
+truncation. For example:
 
     $ COLUMNS=500 dpkg -l | jc --dpkg-l
 
@@ -14,6 +15,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('dpkg_l', dpkg_command_output)
+
+    or
+
     import jc.parsers.dpkg_l
     result = jc.parsers.dpkg_l.parse(dpkg_command_output)
 
@@ -69,7 +75,7 @@ Examples:
         "name": "acpid",
         "version": "1:2.0.28-1ubuntu1",
         "architecture": "amd64",
-        "description": "Advanced Configuration and Power Interface event daemon",
+        "description": "Advanced Configuration and Power Interface...",
         "desired": "remove",
         "status": "half installed"
       },
@@ -113,7 +119,7 @@ Examples:
         "name": "acpid",
         "version": "1:2.0.28-1ubuntu1",
         "architecture": "amd64",
-        "description": "Advanced Configuration and Power Interface event daemon"
+        "description": "Advanced Configuration and Power Interface..."
       },
       {
         "codes": "pn",
@@ -135,9 +141,6 @@ class info():
     description = '`dpkg -l` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-    # details = 'enter any other details here'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux']
     magic_commands = ['dpkg -l']
 
@@ -210,7 +213,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
