@@ -6,6 +6,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('hash', hash_command_output)
+
+    or
+
     import jc.parsers.hash
     result = jc.parsers.hash.parse(hash_command_output)
 
@@ -42,8 +47,6 @@ class info():
     description = '`hash` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
 
 
@@ -78,7 +81,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
