@@ -1,8 +1,12 @@
 """jc - JSON CLI output utility `INI` file parser
 
-Parses standard `INI` files and files containing simple key/value pairs. Delimiter can be `=` or `:`. Missing values are supported. Comment prefix can be `#` or `;`. Comments must be on their own line.
+Parses standard `INI` files and files containing simple key/value pairs.
+Delimiter can be `=` or `:`. Missing values are supported. Comment prefix
+can be `#` or `;`. Comments must be on their own line.
 
-Note: Values starting and ending with quotation marks will have the marks removed. If you would like to keep the quotation marks, use the `-r` command-line argument or the `raw=True` argument in `parse()`.
+Note: Values starting and ending with quotation marks will have the marks
+removed. If you would like to keep the quotation marks, use the `-r`
+command-line argument or the `raw=True` argument in `parse()`.
 
 Usage (cli):
 
@@ -10,16 +14,18 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('ini', ini_file_output)
+
+    or
+
     import jc.parsers.ini
     result = jc.parsers.ini.parse(ini_file_output)
 
 Schema:
 
-    ini or key/value document converted to a dictionary - see configparser standard
-          library documentation for more details.
-
-    Note: Values starting and ending with quotation marks will have the marks removed.
-          If you would like to keep the quotation marks, use the -r or raw=True argument.
+    ini or key/value document converted to a dictionary - see the
+    configparser standard library documentation for more details.
 
     {
       "key1":       string,
@@ -71,8 +77,6 @@ class info():
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     details = 'Using configparser from the standard library'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
 
 
@@ -103,8 +107,12 @@ def _process(proc_data):
 
         # simple key/value files with no headers
         else:
-            if proc_data[heading] is not None and proc_data[heading].startswith('"') and proc_data[heading].endswith('"'):
+            if (proc_data[heading] is not None and
+               proc_data[heading].startswith('"') and
+               proc_data[heading].endswith('"')):
+
                 proc_data[heading] = proc_data[heading].lstrip('"').rstrip('"')
+
             elif proc_data[heading] is None:
                 proc_data[heading] = ''
 
@@ -118,7 +126,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
