@@ -14,6 +14,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('ps', ps_command_output)
+
+    or
+
     import jc.parsers.ps
     result = jc.parsers.ps.parse(ps_command_output)
 
@@ -53,7 +58,7 @@ Examples:
         "stime": "Nov01",
         "tty": null,
         "time": "00:00:11",
-        "cmd": "/usr/lib/systemd/systemd --switched-root --system --deserialize 22"
+        "cmd": "/usr/lib/systemd/systemd --switched-root --system --dese..."
       },
       {
         "uid": "root",
@@ -88,7 +93,7 @@ Examples:
         "stime": "Nov01",
         "tty": "?",
         "time": "00:00:11",
-        "cmd": "/usr/lib/systemd/systemd --switched-root --system --deserialize 22"
+        "cmd": "/usr/lib/systemd/systemd --switched-root --system --dese..."
       },
       {
         "uid": "root",
@@ -126,7 +131,7 @@ Examples:
         "stat": "Ss",
         "start": "Nov09",
         "time": "0:08",
-        "command": "/usr/lib/systemd/systemd --switched-root --system --deserialize 22"
+        "command": "/usr/lib/systemd/systemd --switched-root --system --..."
       },
       {
         "user": "root",
@@ -170,7 +175,7 @@ Examples:
         "stat": "Ss",
         "start": "Nov09",
         "time": "0:08",
-        "command": "/usr/lib/systemd/systemd --switched-root --system --deserialize 22"
+        "command": "/usr/lib/systemd/systemd --switched-root --system --..."
       },
       {
         "user": "root",
@@ -211,8 +216,6 @@ class info():
     description = '`ps` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'cygwin', 'aix', 'freebsd']
     magic_commands = ['ps']
 
@@ -269,7 +272,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
