@@ -1,6 +1,7 @@
 """jc - JSON CLI output utility `timedatectl` command output parser
 
-The `epoch_utc` calculated timestamp field is timezone-aware and is only available if the `universal_time` field is available.
+The `epoch_utc` calculated timestamp field is timezone-aware and is only
+available if the `universal_time` field is available.
 
 Usage (cli):
 
@@ -12,6 +13,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('timedatectl', timedatectl_command_output)
+
+    or
+
     import jc.parsers.timedatectl
     result = jc.parsers.timedatectl.parse(timedatectl_command_output)
 
@@ -20,7 +26,7 @@ Schema:
     {
       "local_time":                        string,
       "universal_time":                    string,
-      "epoch_utc":                         integer,     # timezone-aware timestamp
+      "epoch_utc":                         integer,     # timezone-aware
       "rtc_time":                          string,
       "time_zone":                         string,
       "ntp_enabled":                       boolean,
@@ -67,9 +73,6 @@ class info():
     description = '`timedatectl status` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
-    # details = 'enter any other details here'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux']
     magic_commands = ['timedatectl', 'timedatectl status']
 
@@ -109,7 +112,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
