@@ -2,9 +2,12 @@
 
 Supports `traceroute` and `traceroute6` output.
 
-Note: On some operating systems you will need to redirect `STDERR` to `STDOUT` for destination info since the header line is sent to `STDERR`. A warning message will be printed to `STDERR` if the header row is not found.
+Note: On some operating systems you will need to redirect `STDERR` to
+      `STDOUT` for destination info since the header line is sent to
+      `STDERR`. A warning message will be printed to `STDERR` if the
+      header row is not found.
 
-e.g. `$ traceroute 8.8.8.8 2>&1 | jc --traceroute`
+      e.g. `$ traceroute 8.8.8.8 2>&1 | jc --traceroute`
 
 Usage (cli):
 
@@ -16,6 +19,11 @@ Usage (cli):
 
 Usage (module):
 
+    import jc
+    result = jc.parse('traceroute', traceroute_command_output)
+
+    or
+
     import jc.parsers.traceroute
     result = jc.parsers.traceroute.parse(traceroute_command_output)
 
@@ -124,8 +132,6 @@ class info():
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     details = 'Using the trparse library by Luis Benitez at https://github.com/lbenitez000/trparse'
-
-    # compatible options: linux, darwin, cygwin, win32, aix, freebsd
     compatible = ['linux', 'darwin', 'freebsd']
     magic_commands = ['traceroute', 'traceroute6']
 
@@ -361,7 +367,7 @@ def parse(data, raw=False, quiet=False):
     Parameters:
 
         data:        (string)  text data to parse
-        raw:         (boolean) output preprocessed JSON if True
+        raw:         (boolean) unprocessed output if True
         quiet:       (boolean) suppress warning messages if True
 
     Returns:
